BlendRGBList: Blend a list of colors

View source: R/colors.R

BlendRGBListR Documentation

Blend a list of colors

Description

Blend multiple colors with alpha channels into a single color using a specified blending mode.

Usage

BlendRGBList(Clist, mode = "blend", RGB_BackGround = c(1, 1, 1))

Arguments

Clist

A list of colors, where each color is a list containing RGB values and alpha channel.

mode

The blending mode to use. One of "blend", "average", "screen", or "multiply". Default is "blend".

RGB_BackGround

The background RGB color to composite with. Default is c(1, 1, 1) (white).

Value

A numeric vector of RGB values.


thisplot documentation built on March 7, 2026, 5:07 p.m.