| adjustlayout | R Documentation |
Adjust the layout of a graph to prevent node overlaps by considering node widths and heights.
adjustlayout(graph, layout, width, height = 2, scale = 100, iter = 100)
graph |
An igraph graph object. |
layout |
A matrix with two columns representing the initial layout coordinates. |
width |
A numeric vector of node widths. |
height |
The height constraint for nodes.
Default is |
scale |
The scaling factor for the layout.
Default is |
iter |
The number of iterations for the adjustment algorithm.
Default is |
A matrix with adjusted layout coordinates.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.