extractgrobs: Extract grobs from a list

View source: R/plot.R

extractgrobsR Documentation

Extract grobs from a list

Description

Extract grobs from a named list of grobs based on the specified x and y indices.

Usage

extractgrobs(vlnplots, x_nm, y_nm, x, y)

Arguments

vlnplots

A named list of grobs.

x_nm

A character vector of names for the x dimension.

y_nm

A character vector of names for the y dimension.

x

An integer index for the x dimension.

y

An integer index for the y dimension.

Value

The extracted grob(s).


thisplot documentation built on March 7, 2026, 5:07 p.m.