grid_draw: Draw grobs at specified positions

View source: R/plot.R

grid_drawR Documentation

Draw grobs at specified positions

Description

Draw a list of grobs at specified positions with given widths and heights.

Usage

grid_draw(groblist, x, y, width, height)

Arguments

groblist

A grob or a list of grobs to draw.

x

A numeric vector of x positions for each grob.

y

A numeric vector of y positions for each grob.

width

A numeric vector of widths for each grob.

height

A numeric vector of heights for each grob.

Value

No return value, called for side effects (drawing grobs).


thisplot documentation built on March 7, 2026, 5:07 p.m.