make_long: Make a long data frame for sankey plot

View source: R/sankey.R

make_longR Documentation

Make a long data frame for sankey plot

Description

Prepares a 'wide' data frame into a format that 'geom_sankey' or 'geom_alluvial' understands. Useful to show flows between dimensions in dataset.

Usage

make_long(.df, ..., value = NULL)

Arguments

.df

a data frame

...

unquoted columnnames of df that you want to include in the plot.

value

if each row have a weight this weight could be kept by providing column name of weight.

Value

a longer data frame


thisplot documentation built on March 7, 2026, 5:07 p.m.