standardise: Standardize data by rows

View source: R/plot.R

standardiseR Documentation

Standardize data by rows

Description

Standardize each row of a data matrix by subtracting the mean and dividing by the standard deviation.

Usage

standardise(data)

Arguments

data

A matrix or data frame to standardize.

Value

The standardized data with the same structure as input.


thisplot documentation built on March 7, 2026, 5:07 p.m.