| BlendRGBList | R Documentation |
Blend multiple colors with alpha channels into a single color using a specified blending mode.
BlendRGBList(Clist, mode = "blend", RGB_BackGround = c(1, 1, 1))
Clist |
A list of colors, where each color is a list containing RGB values and alpha channel. |
mode |
The blending mode to use.
One of |
RGB_BackGround |
The background RGB color to composite with.
Default is |
A numeric vector of RGB values.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.