| blendcolors | R Documentation |
Blends a list of colors using the specified blend mode
blendcolors(colors, mode = c("blend", "average", "screen", "multiply"))
colors |
Color vectors. |
mode |
Blend mode.
One of |
A character vector of hexadecimal color codes representing the blended color.
blend <- c(
"red",
"green",
blendcolors(c("red", "green"),
mode = "blend"
)
)
average <- c(
"red",
"green",
blendcolors(c("red", "green"),
mode = "average"
)
)
screen <- c(
"red",
"green",
blendcolors(c("red", "green"),
mode = "screen"
)
)
multiply <- c(
"red",
"green",
blendcolors(c("red", "green"),
mode = "multiply"
)
)
show_palettes(
list(
"blend" = blend,
"average" = average,
"screen" = screen,
"multiply" = multiply
)
)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.