| extractgrobs | R Documentation |
Extract grobs from a named list of grobs based on the specified x and y indices.
extractgrobs(vlnplots, x_nm, y_nm, x, y)
vlnplots |
A named list of grobs. |
x_nm |
A character vector of names for the x dimension. |
y_nm |
A character vector of names for the y dimension. |
x |
An integer index for the x dimension. |
y |
An integer index for the y dimension. |
The extracted grob(s).
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.