Creates an alluvial plot which visualize flows between nodes. Each observation needs to have a `x` aesthetic as well as a `next_x` column which declares where that observation should flow. Also each observation should have a `node` and a `next_node` aesthetic which provide information about which group in the y-direction.
geom_alluvial(
mapping = NULL,
data = NULL,
position = "identity",
na.rm = FALSE,
show.legend = NA,
space = 0,
width = 0.1,
smooth = 8,
inherit.aes = TRUE,
...
)A ggplot layer.
Provide you own mapping. Both x and y need to be numeric.
Provide you own data.
Change position.
Remove missing values.
Show legend in plot.
Space between nodes in the y-direction.
Width of nodes.
How much smooth should the curve have? More means steeper curve.
Should the geom inherit aesthetics.
Other arguments to be passed to the geom.