Creates centered labels or text in nodes of your alluvial plot. Needs to have the exact same aesthetics as the call to `geom_alluvial` to work.
geom_alluvial_text(
mapping = NULL,
data = NULL,
position = "identity",
na.rm = FALSE,
show.legend = NA,
space = 0,
width = 0.1,
inherit.aes = TRUE,
...
)geom_alluvial_label(
mapping = NULL,
data = NULL,
position = "identity",
na.rm = FALSE,
show.legend = NA,
space = 0,
width = 0.1,
inherit.aes = TRUE,
...
)
A ggplot layer.
Provide you own mapping. Both x and y need to be numeric.
Provide you own data.
Change position.
Remove missing values.
Show legend in plot.
Space between nodes in the y-direction.
Width of nodes.
Should the geom inherit aesthetics.
Other arguments to be passed to the geom.
Other important arguments are; `space` which provides the space between nodes in the y-direction; `shift` which shifts nodes in the y-direction.