| get_colors | R Documentation |
Search for colors in the Chinese colors dataset and all available palettes. This function can search by palette names, color names (pinyin or Chinese), numbers, or hex codes. It automatically searches in all palettes and reports which palette(s) contain the found colors.
get_colors(..., palettes = NULL)
... |
One or more search values. Can be palette names, color names (pinyin or Chinese), numbers, or hex codes. If NULL, using all Chinese colors. |
palettes |
Optional. A named list of palettes to search in.
If |
A data frame with class colors containing matching color information.
The result is automatically printed using print.colors().
chinese_colors for the dataset of Chinese traditional colors. get_chinese_palettes for getting Chinese color palettes. ChineseColors for the ChineseColors object.
get_colors("Paired")
get_colors("#FF7F00")
get_colors("pinlan")
get_colors(44)
get_colors("#2B73AF")
get_colors("cyan", palettes = "ChineseSet64")
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.