| grid_draw | R Documentation |
Draw a list of grobs at specified positions with given widths and heights.
grid_draw(groblist, x, y, width, height)
groblist |
A grob or a list of grobs to draw. |
x |
A numeric vector of x positions for each grob. |
y |
A numeric vector of y positions for each grob. |
width |
A numeric vector of widths for each grob. |
height |
A numeric vector of heights for each grob. |
No return value, called for side effects (drawing grobs).
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.