| heatmap_fixsize | R Documentation |
Compute fixed heatmap device size
heatmap_fixsize(
width,
width_sum,
height,
height_sum,
units,
ht_list,
legend_list
)
width |
Optional user-provided target width. If |
width_sum |
Numeric baseline width used when heatmap body size is in
|
height |
Optional user-provided target height. If |
height_sum |
Numeric baseline height used when heatmap body size is in
|
units |
Output unit string passed to grid conversion helpers, such as
|
ht_list |
A |
legend_list |
A list of |
A list with two converted units: ht_width and ht_height.
mat <- matrix(rnorm(100), nrow = 10)
ht <- ComplexHeatmap::Heatmap(mat, name = "expr")
lgd <- list(ComplexHeatmap::Legend(title = "expr", at = c(-2, 0, 2)))
out <- heatmap_fixsize(
width = NULL,
width_sum = 6,
height = NULL,
height_sum = 4,
units = "in",
ht_list = ht,
legend_list = lgd
)
out
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.