| normalize_drawable | R Documentation |
Normalize drawable objects to grobs
normalize_drawable(obj)
obj |
A drawable object, such as a ggplot, patchwork, or grid grob. |
A grid grob object. If the input is not drawable, returns a null grob.
library(ggplot2)
p <- ggplot2::ggplot(mtcars, ggplot2::aes(wt, mpg)) +
ggplot2::geom_point()
g <- normalize_drawable(p)
p + g
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.