powered by
Normalize drawable objects to grobs
normalize_drawable(obj)
A grid grob object. If the input is not drawable, returns a null grob.
A drawable object, such as a ggplot, patchwork, or grid grob.
library(ggplot2) p <- ggplot2::ggplot(mtcars, ggplot2::aes(wt, mpg)) + ggplot2::geom_point() g <- normalize_drawable(p) p + g
Run the code above in your browser using DataLab