| standardise | R Documentation |
Standardize each row of a data matrix by subtracting the mean and dividing by the standard deviation.
standardise(data)
data |
A matrix or data frame to standardize. |
The standardized data with the same structure as input.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.